/*
 *	@(#)tables.ddl	9.1 6/14/93
 */

//XXXXMANUFACTURER STANDARD, DEVICE_TYPE _TABLES, DEVICE_REVISION 6, DD_REVISION 1
/* This file conforms to the document:
 *     HART Smart Communications Protocol - Common Tables,
 *     Revision 6.0
 */

//XXXX#include "macros.ddl"

/*
 * Table 1. Unique (Rosemount and subsidiaries) Device Type Codes
 * NOTE- Using the word Rosemount in the Table name was an artifact.
 * NOTE- This is really not a true Table but is really set of unique Tables
 * that uses another VARIABLE (i.e. company_identification_code) as
 * an index into the array of Tables. Together the combination of the array
 * index and the referenced Table, a company unique HART Device is found.
 */
VARIABLE unique_device_type_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Any enumerations in the range from 1-249
	      are not allowed. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
      /*
	  SELECT (company_identification_code)
	  {
			VARIABLE rosemount_model_code
			VARIABLE rosemount_analytical_model_code
			VARIABLE kayray_model_code
			VARIABLE micro_motion_model_code
      }
      */
      { 0,   [ascii_term] },

      { 253, [special] },
      { 254, [expansion] }
  }
  CLASS HART;
}

/*
 * Table 1a. Rosemount Device Type Codes
 * NOTE- VARIABLE company_identification_code = 38
 */
VARIABLE rosemount_model_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Any enumerations in the range from 250-255
	      are not allowable. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	{ 1,  [pressure_3051] },
	{ 2,  [temperature_3044] },
	{ 3,  [pressure_1151s] },
	{ 4,  [mag_flow_8712] },
	{ 5,  [pressure_2001] },
	{ 6,  [pressure_3051c] },

	   /* Design Note: VARIABLE micro_motion_model_code
	      { 7,  [mass_flow_9712] }, implemented HART Revision 4 when
	      there was no VARIABLE company_identification_code, so
	      7 must be kept as 'Reserved' for this place holder. */

	   /* Design Note: VARIABLE kayray_model_code
	      { 8,  [level_4050] } and { 9,  [density_3680] },
	      could implement HART Revision 4 when there was no
	      VARIABLE company_identification_code, so
	      8 and 9 must be kept as 'Reserved' for this place holder. */

	   /* Design Note: VARIABLE rosemount_analytical_model_code
	      { 10, [ph_1054] }, could implemented HART Revision 4 when
	      there was no VARIABLE company_identification_code, so
	      10 must be kept as 'Reserved' for this place holder. */

	{ 11, [pressure_3001l] },
	{ 12, [mag_flow_8712H] },
	{ 13, [temperature_3044C] },
	{ 14, [pressure_3001c] },
	{ 15, [pressure_3051clp] },
	{ 16, [vortex_flow_8800] },
	{ 17, [htg_3201] },
	{ 18, [pressure_1152s] },
	{ 19, [htg_3202] },
	{ 20, [pressure_3001s] }
  }
  CLASS DEVICE;
}

/*
 * Table 1b. Rosemount Analytical (Rosemount subsidiary) Device Type Codes
 * NOTE- VARIABLE company_identification_code = 46
 */
VARIABLE rosemount_analytical_model_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Any enumerations in the range from 250-255
	      are not allowable. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	{ 6,  [ph_1181] },
	{ 7,  [conductivity_1181] },
	{ 10, [ph_1054] },
	{ 11, [conductivity_1054] }
  }
  CLASS DEVICE;
}

/*
 * Table 1c. KayRay (Rosemount subsidiary) Device Type Codes
 * NOTE- VARIABLE company_identification_code = 25
 */
VARIABLE kayray_model_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Any enumerations in the range from 250-255
	      are not allowable. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	{ 8,  [level_4050] },
	{ 9,  [density_3680] },
	{ 15, [steam_quality_3280] }
  }
  CLASS DEVICE;
}

/*
 * Table 1d. Micro Motion (Rosemount subsidiary) Device Type Codes
 * NOTE- VARIABLE company_identification_code = 31
 */
VARIABLE micro_motion_model_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Any enumerations in the range from 250-255
	      are not allowable. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	{ 7,  [mass_flow_9712] },
	{ 21, [mass_flow_9739] }
  }
  CLASS DEVICE;
}


/*
 * Table 2. Unit Codes
 */
VARIABLE units_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

       { 1,   [InH2O],	   [inches_of_water_68_degrees_F_help] },
       { 2,   [InHg],	   [inches_of_mercury_0_degrees_C_help] },
       { 3,   [FtH2O],	   [feet_of_water_68_degrees_F_help] },
       { 4,   [mmH2O],	   [millimeters_of_water_68_degrees_F_help] },
       { 5,   [mmHg],	   [millimeters_of_mercury_0_degrees_C_help] },
       { 6,   [psi],	   [pounds_per_square_inch_help] },
       { 7,   [bar],	   [bars_help] },
       { 8,   [mbar],	   [millibars_help] },
       { 9,   [g_SqCm],    [grams_per_square_centimeter_help] },
       { 10,  [kg_SqCm],   [kilograms_per_square_centimeter_help] },
       { 11,  [PA],	   [pascals_help] },
       { 12,  [kPA],	   [kilopascals_help] },
       { 13,  [torr],	   [torr_help] },
       { 14,  [ATM],	   [atmospheres_help] },
       { 15,  [CuFt_min],  [cubic_feet_per_minute_help] },
       { 16,  [gal_min],   [gallons_per_minute_help] },
       { 17,  [l_min],	   [liters_per_minute_help] },
       { 18,  [ImpGal_min],[imperial_gallons_per_minute_help] },
       { 19,  [CuMtr_hr],  [cubic_feet_per_hour_help] },
       { 20,  [ft_s],	   [feet_per_second_help] },
       { 21,  [mtr_s],	   [meters_per_second_help] },
       { 22,  [gal_s],	   [gallons_per_second_help] },
       { 23,  [MilGal_day],[million_gallons_per_day_help] },
       { 24,  [l_s],	   [liters_per_second_help] },
       { 25,  [MilL_day],  [million_liters_per_day_help] },
       { 26,  [CuFt_s],    [cubic_feet_per_second_help] },
       { 27,  [CuFt_day],  [cubic_feet_per_day_help] },
       { 28,  [CuMtr_s],   [cubic_meters_per_second_help] },
       { 29,  [CuMtr_day], [cubic_meters_per_day_help] },
       { 30,  [ImpGal_hr], [imperial_gallons_per_hour_help] },
       { 31,  [ImpGal_day],[imperial_gallons_per_day_help] },
       { 32,  [degC],	   [degrees_celsius_help] },
       { 33,  [degF],	   [degrees_fahrenheit_help] },
       { 34,  [degR],	   [degrees_rankine_help] },
       { 35,  [Kelvin],    [degrees_kelvin_help] },
       { 36,  [mV],	   [millivolts_help] },
       { 37,  [Ohm],	   [ohms_help] },
       { 38,  [Hz],	   [hertz_help] },
       { 39,  [mA],	   [milliamperes_help] },
       { 40,  [gal],	   [gallons_help] },
       { 41,  [liter],	   [liters_help] },
       { 42,  [ImpGal],    [imperial_gallons_help] },
       { 43,  [CuMtr],	   [cubic_meters_help] },
       { 44,  [ft],	   [feet_help] },
       { 45,  [meter],	   [meters_help] },
       { 46,  [bbl],	   [barrels_help] },
       { 47,  [in],	   [inches_help] },
       { 48,  [cm],	   [centimeters_help] },
       { 49,  [mm],	   [millimeters_help] },
       { 50,  [min],	   [minutes_help] },
       { 51,  [sec],	   [seconds_help] },
       { 52,  [hr],	   [hours_help] },
       { 53,  [day],	   [days_help] },
       { 54,  [centi_stokes],[centistokes_help] },
       { 55,  [cpoise],    [centipoise_help] },
       { 56,  [uMho],	   [microsiemens_help] },
       { 57,  [Percent],   [percent_help] },
       { 58,  [v],	   [volts_help] },
       { 59,  [pH],	   [pH_help] },
       { 60,  [gram],	   [grams_help] },
       { 61,  [kg],	   [kilograms_help] },
       { 62,  [MetTon],    [metric_tons_help] },
       { 63,  [lb],	   [pounds_help] },
       { 64,  [ShTon],	   [short_tons_help] },
       { 65,  [LTon],	   [long_tons_help] },
       { 70,  [g_s],	   [grams_per_second_help] },
       { 71,  [g_min],	   [grams_per_minute_help] },
       { 72,  [g_hr],	   [grams_per_hour_help] },
       { 73,  [kg_s],	   [kilograms_per_second_help] },
       { 74,  [kg_min],    [kilograms_per_minute_help] },
       { 75,  [kg_hr],	   [kilograms_per_hour_help] },
       { 76,  [kg_day],    [kilograms_per_day_help] },
       { 77,  [MetTon_min],[metric_tons_per_minute_help] },
       { 78,  [MetTon_hr], [metric_tons_per_hour_help] },
       { 79,  [MetTon_day],[metric_tons_per_day_help] },
       { 80,  [lb_s],	   [pounds_per_second_help] },
       { 81,  [lb_min],    [pounds_per_minute_help] },
       { 82,  [lb_hr],	   [pounds_per_hour_help] },
       { 83,  [lb_day],    [pounds_per_day_help] },
       { 84,  [ShTon_min], [short_tons_per_minute_help] },
       { 85,  [ShTon_hr],  [short_tons_per_hour_help] },
       { 86,  [ShTon_day], [short_tons_per_day_help] },
       { 87,  [LTon_hr],   [long_tons_per_hour_help] },
       { 88,  [LTon_day],  [long_tons_per_day_help] },
       { 90,  [SGU],	   [specific_gravity_units_help] },
       { 91,  [g_CuCm],    [grams_per_cubic_centimeter_help] },
       { 92,  [kg_CuMtr],  [kilograms_per_cubic_meter_help] },
       { 93,  [lb_gal],    [pounds_per_gallon_help] },
       { 94,  [lb_CuFt],   [pounds_per_cubic_foot_help] },
       { 95,  [g_ml],	   [grams_per_milliliter_help] },
       { 96,  [kg_l],	   [kilograms_per_liter_help] },
       { 97,  [g_l],	   [grams_per_liter_help] },
       { 98,  [lb_CuIn],   [pounds_per_cubic_inch_help] },
       { 99,  [ShTon_CuYd],[short_tons_per_cubic_yard_help] },
       { 100, [degTwad],   [degrees_twaddell_help] },
       { 101, [degBrix],   [degrees_brix_help] },
       { 102, [degBaum_hv],[degrees_baume_heavy_help] },
       { 103, [degBaum_lt],[degrees_baume_light_help] },
       { 104, [degAPI],    [degrees_API_help] },
       { 105, [Percent_sol_wt],[percent_solids_per_weight_help] },
       { 106, [Percent_sol_vol],[percent_solids_per_volume_help] },
       { 107, [degBall],   [degrees_balling_help] },
       { 108, [proof_vol], [proof_per_volume_help] },
       { 109, [proof_mass],[proof_per_mass_help] },
       { 110, [bush],	   [bushels_help] },
       { 111, [CuYd],	   [cubic_yards_help] },
       { 112, [CuFt],	   [cubic_feet_help] },
       { 113, [CuIn],	   [cubic_inches_help] },
       { 120, [mtr_hr],    [meters_per_hour_help] },
       { 130, [CuFt_hr],   [cubic_feet_per_hour_help] },
       { 131, [CuMtr_min], [cubic_meters_per_minute_help] },
       { 132, [bbl_s],	   [barrels_per_second_help] },
       { 133, [bbl_min],   [barrels_per_minute_help] },
       { 134, [bbl_hr],    [barrels_per_hour_help] },
       { 135, [bbl_day],   [barrels_per_day_help] },
       { 136, [gal_hr],    [gallons_per_hour_help] },
       { 137, [ImpGal_s],  [imperial_gallons_per_second_help] },
       { 138, [l_hr],	   [liters_per_hour_help] },
       { 150, [percent_StmQual],[percent_steam_quality_help] },
       { 151, [Ftin16],    [feet_inches_sixteenths_help] },
       { 152, [CuFt_lb],   [cubic_feet_per_pound_help] },
       { 153, [pico_farads],[picofarads_help] },
       { 160, [Percent_plato],[percent_plato_help] },
       { 235, [gallons_per_day],[gallons_per_day_help] },
       { 236, [hecto_liter],[hectoliters_help] },
       { 237, [mega_pascals],[megapascals_help] },
       { 238, [in_H2O_4_degrees_C],[inches_of_water_4_degrees_C_help] },
       { 239, [mm_H2O_4_degrees_C],[millimeters_of_water_4_degrees_C_help] },
       { 250, [not_used] },
       { 251, [none] },
       { 252, [unknown] },
       { 253, [special] }
  }
  CLASS USER_INTERFACE;
}

/*
 * Table 3. Transfer Function Codes
 */
VARIABLE transfer_function_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

      { 0,   [linear],	   [linear_help] },
      { 1,   [square_root],[square_root_help] },
      { 2,   [square_root_to_the_third_power], [square_root_third_power_help] },
      { 3,   [square_root_to_the_fifth_power], [square_root_fifth_power_help] },
      { 4,   [special_curve],[special_curve_help] },
      { 231, [square_root_plus_special_curve],[square_root_plus_special_curve_help] },
      { 232, [square_root_to_the_third_power_plus_special_curve],[square_root_third_power_plus_special_curve_help] },
      { 233, [square_root_to_the_fifth_power_plus_special_curve],[square_root_fifth_power_plus_special_curve_help] },
      { 250, [not_used] },
      { 251, [none] },
      { 252, [unknown] },
      { 253, [special] }
  }
  CLASS USER_INTERFACE;
}

/*
 * Table 4. Material Codes
 */
VARIABLE material_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: The materials in this table should be
	      solids at 72 Degrees Fahrenheit. */
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */
	   /* Note:
	      Ryton is a registered trademark of Phillips Petroleum Company.
	      Kynar is a trademark of Pennwalt Incorporated.
	      Hastelloy C is a trademark of Cabot Corporation.
	      Teflon and Kalrez are registered trademarks of E. I. DuPont De
	      Nemours Company.
	      Inconel is a trademark of International Nickel Company. */

       { 0,   [carbon_steel],	     [carbon_steel_help] },
       { 1,   [stainless_steel_304], [stainless_steel_304_help] },
       { 2,   [stainless_steel_316], [stainless_steel_316_help] },
       { 3,   [hastelloy_c],	     [hastelloy_c_help] },
       { 4,   [monel],		     [monel_help] },
       { 5,   [tantalum],	     [tantalum_help] },
       { 6,   [titanium],	     [titanium_help] },
       { 7,   [pt_ir],		     [platinum_iridium_help] },
       { 8,   [alloy_20],	     [alloy_20_help] },
       { 9,   [co_cr_ni],	     [cobalt_chromium_nickel_help] },
       { 10,  [ptfe],		     [ptfe_teflon_help] },
       { 11,  [vito],		     [viton_help] },
       { 12,  [buna_n], 	     [buna_n_help] },
       { 13,  [ethyl_prop],	     [ethyl_prop_help] },
       { 14,  [urethane],	     [urethane_help] },
       { 15,  [gold],		     [gold_help] },
       { 16,  [tefzel], 	     [tefzel_help] },
       { 17,  [ryton],		     [ryton_help] },
       { 18,  [ceramic],	     [ceramic_help] },
       { 19,  [stainless_steel_316l],[stainless_steel_316l_help] },
       { 20,  [pvc],		     [pvc_help] },
       { 21,  [nitrile_rubber],      [nitrile_rubber_help] },
       { 22,  [kalrez], 	     [kalrez_help] },
       { 23,  [inconel],	     [inconel_help] },
       { 24,  [kynar],		     [kynar_help] },
       { 25,  [aluminium],	     [aluminum_help] },
       { 26,  [nickel], 	     [nickel_help] },
       { 30,  [hastelloy_c276],      [hastelloy_c_276_help] },
       { 239, [monel_400],	     [monel_400_help] },
       { 250, [not_used] },
       { 251, [none] },
       { 252, [unknown] },
       { 253, [special] }
  }
  CLASS USER_INTERFACE;
}

/*
 * Table 4. NULL
 */


/*
 * Table 6. Alarm Selection Codes
 */
VARIABLE alarm_selection_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

      { 0,   [high],	  [high_help] },
      { 1,   [low],	  [low_help] },
      { 239, [hold_last_output_value], [hold_last_output_value_help] },
      { 250, [not_used] },
      { 251, [none] },
      { 252, [unknown] },
      { 253, [special] }
  }
  CLASS USER_INTERFACE;
}

/*
 * Tables 7. Write Protect Codes
 */
VARIABLE write_protect_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

      { 0,   [no], [not_write_protected] },
      { 1,   [yes], [write_protected] },

      { 250, [not_used] },
      { 251, [none] },
      { 252, [unknown] },
      { 253, [special] }
  }
  CLASS DEVICE;
}

/*
 * Tables 8. Company (Manufacturer) Identification Codes
 * Note- Manufacturer is an improper word to use, since this set of
 * enumerations may be used in variables that describe the OEM company.
 */
VARIABLE company_identification_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */
	   /* Design Note: The 'Unique Identifier' of the HART Frame
	      is composed of: (from most significant VARIABLE to least
	      significant VARIABLE: company_identification_code, *_model_code,
	      device_id) & (0x3FFFFFFFFF). Thus the meaning of the most
	      significant two bits of the 'Unique Identifier' are removed,
	      and thus are removed from the company_identification_code. This
	      then makes enumerations > 0x3F = 63 potentially not unique from
	      a HART Protocol viewpoint. To alleviate this problem a suggestion
	      should be made to the companies with enumerations > 63 to start
	      their allocation of *_model_code's from 249 backwards to 0. */

      { 1,   [Acromag] },
      { 2,   [Allen_Bradley] },
      { 3,   [Ametek] },
      { 4,   [Analog_Devices] },
      { 5,   [Bailey] },
      { 6,   [Beckman] },
      { 7,   [Bell_Microsensor] },
      { 8,   [Bourns] },
      { 9,   [Bristol_Babcock] },
      { 10,  [Brooks_Instrument] },
      { 11,  [Chessell] },
      { 12,  [Combustion_Engineering] },
      { 13,  [Daniel_Industries] },
      { 14,  [Delta] },
      { 15,  [Dieterich_Standard] },
      { 16,  [Dohrmann] },
      { 17,  [Endress_and_Hauser] },
      { 18,  [Fischer_and_Porter] },
      { 19,  [Fisher_Controls] },
      { 20,  [Foxboro] },
      { 21,  [Fuji] },
      { 22,  [Hartmann_and_Braun] },
      { 23,  [Honeywell] },
      { 24,  [ITT_Barton] },
      { 25,  [KayRay_Sensall] },
      { 26,  [Kent] },
      { 27,  [Leeds_and_Northrup] },
      { 28,  [Leslie] },
      { 29,  [M_System_Co] },
      { 30,  [Measurex] },
      { 31,  [Micro_Motion] },
      { 32,  [Moore_Industries] },
      { 33,  [Moore_Products] },
      { 34,  [Ohkura_Electric] },
      { 35,  [Paine] },
      { 36,  [Rochester_Instrument_Systems] },
      { 37,  [Ronan] },
      { 38,  [Rosemount] },
      { 39,  [Sarasota_Automation] },
      { 40,  [Schlumberger] },
      { 41,  [Sensall] },
      { 42,  [Siemens] },
      { 43,  [Camille_Bauer] },
      { 44,  [Toshiba] },
      { 45,  [Transmation] },
      { 46,  [Rosemount_Analytical] },
      { 47,  [Valmet] },
      { 48,  [Valtek] },
      { 49,  [Varec] },
      { 50,  [Viatran] },
      { 51,  [Weed] },
      { 52,  [Westinghouse] },
      { 53,  [Xomox] },
      { 54,  [Yamatake] },
      { 55,  [Yokogawa] },
      { 56,  [Nuovo_Pignone] },
      { 57,  [Promac] },
      { 58,  [Exac_Corporation] },
      { 59,  [KDG_Mobrey] },
      { 60,  [Acrom_Control_System] },
      { 61,  [Princo] },
      { 62,  [Smar] },
      { 63,  [Eckardt] },
      { 64,  [Measurement_Technology] },
      { 65,  [Applied_System_Technologies] },
      { 66,  [Samson] },
      { 67,  [Sparling_Instruments] },
      { 68,  [Fireye] },
      { 69,  [Krohne] },
      { 70,  [Betz_Equipment] },
      { 71,  [Druck] },
      { 72,  [SOR] },
      { 73,  [Elcon_Instruments] },
      { 74,  [EMCO] },
      { 100, [Oval] },
      { 108, [Bopp_and_Reuther_Heinrichs] },

      { 250, [not_used] },
      { 251, [none] },
      { 252, [unknown] },
      { 253, [special] }
  }
  CLASS HART;
}


/*
 * Tables 9. Burst Mode Control Codes
 */
VARIABLE burst_mode_control_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

      { 0, [off] },
      { 1, [on] },

      { 250, [not_used] },
      { 251, [none] },
      { 252, [unknown] },
      { 253, [special] }
  }
  CLASS HART;
}

/*
 * Tables 10. Physical Signaling Codes
 */
VARIABLE physical_signaling_codes
{
  TYPE ENUMERATED
  {
	   /* Design Note: Enumeration 7 is 'Reserved',
	      potentially for an expansion indication. */
	   /* Design Note: Any enumerations in the range from 8-255
	      are not allowable. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

      { 0, [bell_202_current] },
      { 1, [bell_202_voltage] },
      { 2, [rs_485] }
  }
  CLASS DEVICE;
}

/*
 * Tables 11. Flag Assignments
 */
VARIABLE flag_assignment
{
  TYPE ENUMERATED
  {
	   /* Design Note: Bit# 0x07 is 'Reserved',
	      potentially for an expansion indication. */
	   /* Design Note: Any bit not covered by another "Design
	      Note" is 'Undefined'. */

      { 0x01, [Multisens_Dev], [multi_sensor_fld_dev] },
      { 0x02, [EEPROM_Ctrl] },
      { 0x04, [protocol_bridge_device] }
  }
  CLASS HART;
}

/*
 * Tables 12. Transfer Service Function Codes
 * (NOT APPROVED FOR USE)
 */

/*
 * Tables 13. Transfer Service Identifier Codes
 * (NOT APPROVED FOR USE)
 */

/*
 * Tables 14. Operating Mode Codes
 */
VARIABLE operating_mode_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	  { 0,	[normal] }
  }
  CLASS DEVICE;
}

/*
 * Tables 15. Analog Output Numbers Codes
 */
VARIABLE analog_output_numbers_code
{
  TYPE ENUMERATED
  {
	   /* Design Note: Leave 240-249 Undefined for future use. */
	   /* Design Note: Any enumerations in the range from 250-255
	      are 'Reserved' for a single definition if not defined. */
	   /* Design Note: Any enumeration not covered by another "Design
	      Note" is 'Undefined'. */

	  { 1,	[analog_output_1], [analog_output_1_help] },
	  { 2,	[analog_output_2], [analog_output_2_help] },
	  { 3,	[analog_output_3], [analog_output_3_help] },
	  { 4,	[analog_output_4], [analog_output_4_help] }
  }
  CLASS USER_INTERFACE;
}
