/*--------------------------------------------------------------------------------------*/
/*	Copyright (C)  Bopp & Reuther Heinrichs Messtechnik 1999 All Rights Reserved.       */
/*	                                                                                    */
/*	Filename:           ES.DDL                                                          */
/*	Device:             Variable Area Transmitter ES                                    */
/*	Description:        HART Device Description                                         */
/*	Dictionary:         SIHADC01.dct, BR__TF_ES.dct                                     */
/*	Author:             Flegel, Jens (ICS GmbH)                                         */
/*	Manufacturer:       Bopp & Reuther Heinrichs Messtechnik                            */
/*	Univ. Revision:     5                                                               */
/*	Device Revision:    2                                                               */
/*	DD Revision:        1                                                               */
/*	                                                                                    */
/*	$Revision:   1.1  $                                                                 */
/*	$Date:   Feb 24 2000 12:08:46  $                                                    */
/*--------------------------------------------------------------------------------------*/


/*--------------------------- H E A D E R S ----------------------------*/

#include "bi_codes.h"

/*---------------------------- M A C R O S -----------------------------*/

#include "BR__macrosPDM.ddl"

/*----------------------- D E C L A R A T I O N S ----------------------*/



MANUFACTURER BOPP_AND_REUTHER_HEINRICHS, DEVICE_TYPE 0xec, DEVICE_REVISION 2, DD_REVISION 1

// ----- includes

#include "SIHASTIDENT01.inc"

// Verlaufskurve
#define  YT1_LABEL	[menu_dialog_display_measure]
#define  YT1_VALUE	flow_rate.DIGITAL_VALUE
#define  YT1_LRV	flow_rate.LOWER_RANGE_VALUE
#define  YT1_URV	flow_rate.UPPER_RANGE_VALUE
#include "SI_YT.inc"


/*---------------------------- M A C R O S -----------------------------*/

#define  __ALL_RESPONSE_LIST \
0,	SUCCESS,			[no_command_specific_errors];\
2,	DATA_ENTRY_ERROR,	[invalid_selection];\
6,	MISC_ERROR,			[xmtr_specific_command_error];\
7,	MODE_ERROR,			[in_write_protect_mode];

#define  DEVICE_BUSY 32

/*
 **********************************************************************
 *                                                                    *
 * Common Tables                                                      *
 *                                                                    *
 **********************************************************************
*/

#include  "BR__Imp_Tables.ddl"

#include  "BR__Imp_Univ5.ddl"

/*
 **********************************************************************
 *                                                                    *
 * Common Practice Commands                                           *
 *                                                                    *
 **********************************************************************
*/
#include  "BR__Imp_Common7.ddl"

/*
 **********************************************************************
 *                                                                    *
 * Redifinition Standard Menu Device Description                      *
 *                                                                    *
 **********************************************************************
*/
// MENU root_menu
MENU Table_Main_Specialist
{
	LABEL "ES";
	ITEMS
	{
		Tab_ident,						/* menu */
		basic_setup,					/* menu */
		Tab_input,						/* menu */
		Tab_outputs					/* menu */
                Page_selftest,
		Page_display_kennlinie,
	}
}

MENU basic_setup
{
	LABEL  "basic setup""|de|Grundeinstellungen";
	ITEMS
	{
        flow_damping_value (DISPLAY_VALUE)
	}
}

MENU Tab_ident
{
	LABEL	[menu_ident];
	ITEMS
	{
		manufacturer_id,
		device_type,

		//Tab_ident_opunit_universal,
		Tab_ident_device
	}
}

MENU Tab_ident_device
{
	LABEL	"device information" "|de|Gerteinformation";
	ITEMS
	{
//		manufacturer_id,
		device_type,
		device_id,
	//	device_flags,
//		physical_signaling_code,
		universal_revision,
		transmitter_revision,
		software_revision,
	//	hardware_revision,
		write_protect,
		tag (DISPLAY_VALUE),
		descriptor (DISPLAY_VALUE),
		date (DISPLAY_VALUE),
		message (DISPLAY_VALUE),
		final_assembly_number
	}
}

MENU Tab_outputs
{
	LABEL "outputs" "|de|Ausgnge";
	ITEMS
	{
	Tab_current_output,
	Tab_NAMUR
	Tab_totalisator
        }
}

MENU   Tab_current_output
{
	LABEL    "Current output" "|fr|Courant sortie" "|de|Stromausgang";
	ITEMS
	{
	current_output_alarm
	}
}

MENU   Tab_NAMUR
{
	LABEL  "namur switches" "|de|Namurschalter";
	ITEMS
	{
		para_output_status,
		namur_switch
	}
}

MENU   Tab_totalisator
{
	LABEL  "totalizer" "|de|Zhler";
	ITEMS
	{
        totalizer_switch,
totl_units (READ_ONLY)
        }
}

MENU Tab_input
{
	LABEL "input" "|de|Eingang";
	ITEMS
	{
		flow_units (DISPLAY_VALUE),
		para_minlimit,
		para_maxlimit,
//		flow_minimum_span (DISPLAY_VALUE),
		flow_lower_range_value (DISPLAY_VALUE)
		flow_upper_range_value (DISPLAY_VALUE),
		volume_flow_cutoff(DISPLAY_VALUE),
	}
}

MENU Table_Main_Maintenance
{
	LABEL "ES";
	ITEMS
	{
		Tab_ident,						/* menu */
		basic_setup,					/* menu */
		Tab_input,						/* menu */
		Tab_outputs,					/* menu */
                Page_selftest,
Page_display_kennlinie
	}
}
#include  "BR__Imp_Menu.ddl"

#include  "BR__ESMainMenu.ddl"

/*
 **********************************************************************
 *                                                                    *
 *      Variables and Commands                                        *
 *                                                                    *
 **********************************************************************
*/

/*
 *      Dynamic Variables Configuration
 */

ARRAY OF COLLECTION transmitter_variables
{
	HELP [transmitter_variable_help];
	ELEMENTS
	{
		0, flow_rate,      [flow_rate], "Flow Sensor- Hardware that measures flow rate.";
		1, sv, [sv];
	}
}

ARRAY OF COLLECTION dynamic_variables
{
	HELP [dynamic_variable_help];
	ELEMENTS
	{
		PRIMARY, transmitter_variables[0], [pv], [primary_variable_help];
		SECONDARY, transmitter_variables[1], [sv], [secondary_variable_help];
	}
}

/*
 *      Primary Variable
 */
COLLECTION OF VARIABLE flow_rate
{
	LABEL [flow_rate];
	HELP "Flow Sensor- Hardware that measures flow rate.";

	MEMBERS
	{
		/* Measurement */
		DIGITAL_UNITS, flow_units,        [units],  [digital_units_help];
		DIGITAL_VALUE, flow_value,        [blank],  [digital_value_help];
		ANALOG_VALUE,  flow_analog_value, [analog_output_value],[analog_output_help];
		PERCENT_RANGE, flow_percent_range,[percent_of_range], [percent_of_range_help];

		/* Sensor Information */
		SENSOR_UNITS,         flow_units, [sensor_unit],[sensor_minspan_unit_help];
		UPPER_SENSOR_LIMIT,   flow_upper_sensor_limit,[usl],[upper_sensor_limit_help];
		LOWER_SENSOR_LIMIT,   flow_lower_sensor_limit,[lsl],[lower_sensor_limit_help];
		MINIMUM_SPAN,         flow_minimum_span,    [minimum_span],[minimum_span_help];

		/* Device Information */
		SENSOR_SERIAL_NUMBER,	sensor_serial_number,	[sensor_serial_number], [sensor_serial_number_help];

		/* Output Information */
		ALARM_CODE,        flow_alarm_select, [alarm_select],[alarm_code_help];
		TRANSFER_FUNCTION, transfer_function, [transfer_function],[transfer_function_help];
		RANGE_UNITS,       flow_units,      [range_units],[range_units_help];
		UPPER_RANGE_VALUE, flow_upper_range_value,[urv],[upper_range_value_help];
		LOWER_RANGE_VALUE, flow_lower_range_value,[lrv],[lower_range_value_help];
		DAMPING_VALUE,     flow_damping_value, [damping_value],[seconds_damping_value_help];
	}
}
/* ---------------------------------------------------------- */


COLLECTION OF VARIABLE sv
{
	LABEL [sv];
	HELP [secondary_variable_help];
	MEMBERS
	{
		/* Sensor Correction Information */
		DIGITAL_UNITS,		totl_units,		[units],			[digital_units_help];
		DIGITAL_VALUE,		totl_value,		[blank],			[digital_value_help];
	}
}
/******************************************************************************/
/*                                                                            */
/* M E N U S                                                                  */
/*                                                                            */
/******************************************************************************/
/* -------------------------------------------------------------------------- */
/* Menus of 'root_menu'                                                       */
/* -------------------------------------------------------------------------- */
/* > Menus Diag/Service  */




MENU Page_kennlinie
{
	LABEL  "characteristic curve""|de|Kennlinie";
	ITEMS
	{
		Group_Qrel_points_kenn,
		Group_A_B_points_kenn,
		sie_set,
		SEPARATOR,
		save_calibration_method,
		SEPARATOR,
		calibrate_number_of_point,
		calibrate_end_value,
		Atara,
		Btara,
		Amax,
		Bmax
	}
}

MENU Page_display_kennlinie
{
	LABEL  "characteristic curve""|de|Kennlinie";
	ITEMS
	{
		Group_Qrel_points ,
		Group_A_B_points,
		calibrate_number_of_point (READ_ONLY),
		calibrate_end_value (READ_ONLY),
		Atara (READ_ONLY),
		Btara (READ_ONLY),
		Amax (READ_ONLY),
		Bmax (READ_ONLY)
	}
}


MENU Page_wet_calibrate
  {
	LABEL  "Wet calibration|de|Nakalibrierung";
	ITEMS
	{
	//	Group_Qrel_points,
	//	Group_A_B_points,
		Group_wet_calibrate,
		save_calibration_method,
	//	SEPARATOR,
	//	calibrate_number_of_point (READ_ONLY),
	//	Atara (READ_ONLY),
	//	Btara (READ_ONLY),
	//	Amax (READ_ONLY),
	//	Bmax (READ_ONLY)
	}
  }

MENU Page_direct_access
{
	LABEL  "Direct access""|de|Direktzugriff";
	ITEMS
	{
		Group_direct_access,
		save_calibration_method
	}
}

MENU Group_direct_access
{
	LABEL  "Direct access""|de|Direktzugriff";
	ITEMS
	{
		direct_access_index,
		direct_access_data,
		SEPARATOR,
		direct_access_read,
		direct_access_write
	}
}



MENU Group_wet_calibrate
{
	LABEL  "Wet calibration|de|Nakalibrierung";
	ITEMS
	{
		calibrate_point_index,
		SEPARATOR,
		calibrate_point_flow,
		wet_calibrate_method
	}
}



MENU Page_simulation
{
	LABEL  [menu_interface_simulate];
	HELP [simulate_help];
	ITEMS
	{
		editdsp_simulation_default,
		simulation_method,
		simulation_abort_method
	}
}

MENU editdsp_simulation_default
  {
	LABEL  "Default values""|de|Vorgaben";
	ITEMS
	{
		default_Qrel_output,
		default_Qrel,
	SEPARATOR,
		default_current,
		default_N1,
		default_N2
	}
  }



MENU Page_zero_trim
{
	LABEL  [menu_zero_trim];
	ITEMS
	{
		zero_trim_method,
save_calibration_method
//		undo_trim_method
	}
}



MENU Page_reset_change_flag
{
	LABEL  [configuration_flag_reset];
	ITEMS
	{
		reset_change_flag_method
	}
}



MENU Page_selftest
{
	LABEL  [selftest];
	HELP [selftest_help];
	ITEMS
	{
Group_floatmovement,
/*		self_test_Qrel,
		self_test_delta,
		self_test_period,*/
		Group_selftest_mask,
//		current_output_alarm,
	//	method_write_self_test
	}
}


MENU Group_floatmovement
{
	LABEL  "floating body movement""|de|Schwebekrperbewegung";
	ITEMS
	{
		self_test_Qrel,
		self_test_delta,
		self_test_period
	}
}

MENU Group_selftest_mask
{
	LABEL  "Self test mask""|de|Selbsttestmaske";
	ITEMS
	{
		floatmvment,
//		self_test_mask_1 (READ_ONLY),
		local_self_test_mask_1_01,
		local_self_test_mask_1_02,
		local_self_test_mask_1_04,
		local_self_test_mask_1_08,
		local_self_test_mask_1_10,
		local_self_test_mask_1_20
	}
}


/* > Menus Basic Settings */
/* > Menus Detailed Settings */
/* > Menus Qrel-List */

MENU Group_Qrel_points
{
	LABEL  "Qrel table" "|de|Qrel Tabelle";
	ITEMS
	{
		Qrel_Value_00 (READ_ONLY),
		Qrel_Value_01 (READ_ONLY),
		Qrel_Value_02 (READ_ONLY),
		Qrel_Value_03 (READ_ONLY),
		SEPARATOR,
		Qrel_Value_04 (READ_ONLY),
		Qrel_Value_05 (READ_ONLY),
		Qrel_Value_06 (READ_ONLY),
		Qrel_Value_07 (READ_ONLY),
		SEPARATOR,
		Qrel_Value_08 (READ_ONLY),
		Qrel_Value_09 (READ_ONLY),
		Qrel_Value_10 (READ_ONLY),
		Qrel_Value_11 (READ_ONLY),
		SEPARATOR,
		Qrel_Value_12 (READ_ONLY),
		Qrel_Value_13 (READ_ONLY),
		Qrel_Value_14 (READ_ONLY),
		Qrel_Value_15 (READ_ONLY)
	}
}


/* > Menus Qrel-List */

MENU Group_Qrel_points_kenn
{
	LABEL  "Qrel table" "|de|Qrel Tabelle";
	ITEMS
	{
		Qrel_Value_00,
		Qrel_Value_01,
		Qrel_Value_02,
		Qrel_Value_03,
		SEPARATOR,
		Qrel_Value_04,
		Qrel_Value_05,
		Qrel_Value_06,
		Qrel_Value_07,
		SEPARATOR,
		Qrel_Value_08,
		Qrel_Value_09,
		Qrel_Value_10,
		Qrel_Value_11,
		SEPARATOR,
		Qrel_Value_12,
		Qrel_Value_13,
		Qrel_Value_14,
		Qrel_Value_15
	}
}


/* > Menus A-B-List */

MENU Group_A_B_points
{
	LABEL  "A-B table" "|de|A-B Tabelle";
	ITEMS
	{
		A_B_Value_00 (READ_ONLY),
		A_B_Value_01 (READ_ONLY),
		A_B_Value_02 (READ_ONLY),
		A_B_Value_03 (READ_ONLY),
		SEPARATOR,
		A_B_Value_04 (READ_ONLY),
		A_B_Value_05 (READ_ONLY),
		A_B_Value_06 (READ_ONLY),
		A_B_Value_07 (READ_ONLY),
		SEPARATOR,
		A_B_Value_08 (READ_ONLY),
		A_B_Value_09 (READ_ONLY),
		A_B_Value_10 (READ_ONLY),
		A_B_Value_11 (READ_ONLY),
		SEPARATOR,
		A_B_Value_12 (READ_ONLY),
		A_B_Value_13 (READ_ONLY),
		A_B_Value_14 (READ_ONLY),
		A_B_Value_15 (READ_ONLY)
	}
}


/* > Menus A-B-List */

MENU Group_A_B_points_kenn
{
	LABEL  "A-B table" "|de|A-B Tabelle";
	ITEMS
	{
		A_B_Value_00,
		A_B_Value_01,
		A_B_Value_02,
		A_B_Value_03,
		SEPARATOR,
		A_B_Value_04,
		A_B_Value_05,
		A_B_Value_06,
		A_B_Value_07,
		SEPARATOR,
		A_B_Value_08,
		A_B_Value_09,
		A_B_Value_10,
		A_B_Value_11,
		SEPARATOR,
		A_B_Value_12,
		A_B_Value_13,
		A_B_Value_14,
		A_B_Value_15
	}
}


/******************************************************************************/
/*                                                                            */
/* V A R I A B L E S                                                          */
/*                                                                            */
/******************************************************************************/


/* transmitter variables */
VARIABLE        flow_units
{
	LABEL          [units];
	CLASS   INPUT;
	HELP   [flow_units_help];
	TYPE   ENUMERATED
	{
		{ 75, 	units_code (75)		},
		{ 78, 	units_code (78)		},
		{ 72, 	units_code (72)		},
		{ 19, 	units_code (19) 	},
		{ 131, 	units_code (131)	},
		{ 28, 	units_code (28)		},
		{ 138, 	units_code (138)	},
		{ 17, 	units_code (17) 	},
		{ 24, 	units_code (24) 	},
		{ 136, 	units_code (136)	},
		{ 16, 	units_code (16) 	},
		{ 22, 	units_code (22) 	},
		{ 30, 	units_code (30) 	},
		{ 18, 	units_code (18) 	},
		{ 137, 	units_code (137)	},
		{ 48, 	units_code (48)		}
	}
}

VARIABLE      flow_value
{
	LABEL        [flow_rate];
	HANDLING   READ;
	CLASS   DYNAMIC&INPUT;
	HELP   [digital_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      flow_analog_value
{
	LABEL        [pv_analog_value];
	CLASS   ANALOG_OUTPUT&DYNAMIC;
	CONSTANT_UNIT   " mA";
	HELP   [analog_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      flow_percent_range
{
	LABEL        [pv_percent_range];
	CLASS   DYNAMIC&INPUT;
	CONSTANT_UNIT   [Percent];
	HELP   [percent_of_range_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   ".2f";
	}
}

VARIABLE      flow_upper_sensor_limit
{
	LABEL        [usl];
	HANDLING   READ;
	CLASS   CORRECTION;
	HELP   [upper_sensor_limit_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "6.2f";
	}
}

VARIABLE      flow_lower_sensor_limit
{
	LABEL        [lsl];
	HANDLING   READ;
	CLASS   CORRECTION;
	HELP   [lower_sensor_limit_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "6.2f";
	}
}

VARIABLE      flow_minimum_span
{
	LABEL        [minimum_span];
	HANDLING   READ;
	CLASS   INPUT;
	HELP   [minimum_span_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      flow_damping_value
{
	LABEL        [damping_value];
	CLASS   INPUT;
	HELP   [seconds_damping_value_help];
	CONSTANT_UNIT   [sec];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".0f";
		EDIT_FORMAT   "2.0f";
		MAX_VALUE    60.0;
	}
}

VARIABLE      sensor_serial_number
{
	LABEL        [sensor_serial_number];
	HANDLING   READ;
	CLASS   DEVICE;
	HELP   [sensor_serial_number_help];
	TYPE    UNSIGNED_INTEGER(3)
	{
		DISPLAY_FORMAT   "8u";
		EDIT_FORMAT   "8u";
	}
}

VARIABLE        flow_alarm_select
{
	LABEL          [alarm_select];
	HANDLING   READ;
	CLASS   ANALOG_OUTPUT;
	HELP   [alarm_code_help];
	TYPE   ENUMERATED
	{
		{ 251, 	alarm_selection_code(251)	}
	}
}

VARIABLE        transfer_function
{
	LABEL          [transfer_function];
	HANDLING   READ;
	CLASS   ANALOG_OUTPUT;
	HELP   [transfer_function_help];
	TYPE   ENUMERATED
	{
		{ 0, transfer_function_code(0)	}
	}
}

VARIABLE        flow_range_units
{
	LABEL          [pv_range_units];
	CLASS   INPUT;
	HELP   [range_units_help];
	TYPE   ENUMERATED
	{
		{ 75, 	units_code (75)		},
		{ 78, 	units_code (78)		},
		{ 72, 	units_code (72)		},
		{ 19, 	units_code (19) 	},
		{ 131, 	units_code (131)	},
		{ 28, 	units_code (28)		},
		{ 138, 	units_code (138)	},
		{ 17, 	units_code (17) 	},
		{ 24, 	units_code (24) 	},
		{ 136, 	units_code (136)	},
		{ 16, 	units_code (16) 	},
		{ 22, 	units_code (22) 	},
		{ 30, 	units_code (30) 	},
		{ 18, 	units_code (18) 	},
		{ 137, 	units_code (137)	},
		{ 48, 	units_code (48)		}
	}
}

VARIABLE      flow_upper_range_value
{
	LABEL        [urv];
	CLASS   INPUT;
	HELP   [upper_range_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "6.2f";
	}
}

VARIABLE      flow_lower_range_value
{
	LABEL        [lrv];
	HANDLING   READ;
	CLASS   INPUT;
	HELP   [lower_range_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
		EDIT_FORMAT   "6.2f";
	}
}


/* Totalizer */
VARIABLE        totl_units
{
	LABEL          [units];
	HANDLING   READ;
	CLASS   INPUT;
	HELP   [digital_units_help];
	TYPE   ENUMERATED
	{
		{ 61, 	units_code (61)		},
		{ 62, 	units_code (62)		},
		{ 60, 	units_code (60)		},
		{ 43, 	units_code (43)		},
		{ 41, 	units_code (41)		},
		{ 40, 	units_code (40)		},
		{ 42, 	units_code (42)		}
	}
}

VARIABLE      totl_value
{
	LABEL        "counter|de|Zhler";
	HANDLING   READ;
	CLASS   DYNAMIC&INPUT;
	HELP   [digital_value_help];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}


/* settings */
VARIABLE      volume_flow_cutoff
{
	LABEL        "low_flow_cutoff" "|de|Schleichmenge";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [Percent];
	HELP   [low_flow_cutoff_help];
	TYPE    UNSIGNED_INTEGER(2);
}

VARIABLE      para_maxlimit
{
	LABEL        "MAX";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [Percent];
	TYPE    INTEGER(2);
}

VARIABLE      para_minlimit
{
	LABEL        "MIN";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [Percent];
	TYPE    INTEGER(2);
}

VARIABLE        para_output_status
{
	LABEL          "Function|de|Funktion";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0, "1 MAX,2 MIN"   },
		{   	1, "1 IMP,2 MIN"   },
		{   	2, "1 IMP,2 MAX"   },
		{   	3, "1 IMP,2 MIN/MAX"   }
	}
}

VARIABLE        namur_switch
{
	LABEL          "active state""""|de|aktiver Zustand";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{    1, 	"closed""""|de|geschlossen"   },
		{    0, 	"opend""""|de|geffnet"   }
	}
}

VARIABLE        totalizer_switch
{
	LABEL          "totalizer" "|de|Zhler";
	CLASS   INPUT;
	HELP   [totalizer_help];
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}


VARIABLE        default_Qrel_output
{
	LABEL          "setting of" "|de|Vorgabe von";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	1, 	"Qrel"   },
		{   	0, 	"Direct output" "|de|Direkte Vorgabe"   }
	}
}

VARIABLE        simulation_switch
{
	LABEL          "Simulation";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        default_N1
{
	LABEL          "switch N1""|de|Schalter N1";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|ein"  }
	}
}

VARIABLE        default_N2
{
	LABEL          "Switch N2""|de|Schalter N2";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|ein"  }
	}
}

VARIABLE      default_current
{
	LABEL        "current""|de|Strom";
	CLASS   INPUT;
	CONSTANT_UNIT   [mA];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      default_Qrel
{
	LABEL        "Qrel";
	CLASS   INPUT;
	CONSTANT_UNIT   [Percent];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".1f";
	}
}


VARIABLE        floatmvment
{
	LABEL          "Float movement""|de|Schwebekrperbewegung";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0x00, 	"off" "|de|aus"  },
		{   	0x01, 	"alarm if too small" "|de|Alarm, wenn zu klein"   },
		{   	0x02, 	"alarm if too large" "|de|Alarm, wenn zu gro"   }
	}
}

VARIABLE        self_test_mask_1
{
	LABEL          "Self test mask""|de|Selbsttestmaske";
	CLASS   INPUT;
	POST_READ_ACTIONS {    method_read_self_test_mask_1   }
	TYPE   BIT_ENUMERATED
	{
		{   	0x01, 	"Q > 103%"   },
		{   	0x02, 	"Q <> Sensorlimits"   },
		{   	0x04, 	"Sensors too hot/cold" "|de|Sensoren zu hei/kalt"   },
		{   	0x08, 	"A-B not plausible" "|de|A-B nicht sinnvoll"   },
		{   	0x10, 	"totalizer overflow" "|de|Zhlerberlauf"   },
		{   	0x20, 	"MIN/MAX limit" "|de|MIN/MAX-Grenzwert"   }
	}
}

VARIABLE        parity_check
{
	LABEL          "Parity check""|de|Parittprfung";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{    1, 	[yes]  },
		{    0, 	[no]  }
	}
}

VARIABLE      self_test_Qrel
{
	LABEL        "Min Qrel";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [Percent];
	TYPE    UNSIGNED_INTEGER(2);
}

VARIABLE      self_test_delta
{
	LABEL        "Min Delta";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [Percent];
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      self_test_period
{
	LABEL        "Test period""|de|Zeitfenster";
	CLASS   CORRECTION;
	CONSTANT_UNIT   [sec];
	TYPE    UNSIGNED_INTEGER(2)
	{
		MIN_VALUE   0;
		MAX_VALUE    5900;
	}
}

VARIABLE        current_output_alarm
{
	LABEL          "output alarm""|de|Strom bei Alarm";
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{   	0, 	"not_used" "|de|unbenutzt"  },
		{   	1, 	"I < 3.8mA"  },
		{     2, 	"I > 20.5mA"  }
	}
}


VARIABLE        calibrate_unit
{
	LABEL          [units];
	CLASS   INPUT;
	TYPE   ENUMERATED
	{
		{ 75, 	units_code (75)		},
		{ 78, 	units_code (78)		},
		{ 72, 	units_code (72)		},
		{ 19, 	units_code (19) 	},
		{ 131, 	units_code (131)	},
		{ 28, 	units_code (28)		},
		{ 138, 	units_code (138)	},
		{ 17, 	units_code (17) 	},
		{ 24, 	units_code (24) 	},
		{ 136, 	units_code (136)	},
		{ 16, 	units_code (16) 	},
		{ 22, 	units_code (22) 	},
		{ 30, 	units_code (30) 	},
		{ 18, 	units_code (18) 	},
		{ 137, 	units_code (137)	},
		{ 48, 	units_code (48)		}
	}
}

VARIABLE      calibrate_end_value
{
	LABEL        "Calibrated URV""|de|Kalibrierungs-Endwert";
	CLASS   CORRECTION;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      calibrate_number_of_point
{
	LABEL        "Curve point count""|de|Anzahl Sttzstellen";
	CLASS   CORRECTION;
	TYPE    UNSIGNED_INTEGER
	{
		MIN_VALUE   2;
		MAX_VALUE    16;
	}
}


VARIABLE      Atara
{
	LABEL        "Atara";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Btara
{
	LABEL        "Btara";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Amax
{
	LABEL        [Amax];
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Bmax
{
	LABEL        [Bmax];
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

/* calibration */
VARIABLE      calibrate_point_index
{
	LABEL        "Curve point index""|de|Sttzstelle Nr.";
	CLASS   LOCAL;
	TYPE    UNSIGNED_INTEGER
	{
		MIN_VALUE   0;
		MAX_VALUE    15;
	}
}

VARIABLE      calibrate_point_flow
{
	LABEL        "Value""|de|Wert";
	CLASS   LOCAL;
	TYPE    FLOAT
	{
		DISPLAY_FORMAT   ".2f";
	}
}

VARIABLE      Qrel_Value_00
{
	LABEL        "00";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_01
{
	LABEL        "01";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_02
{
	LABEL        "02";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_03
{
	LABEL        "03";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_04
{
	LABEL        "04";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_05
{
	LABEL        "05";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_06
{
	LABEL        "06";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_07
{
	LABEL        "07";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_08
{
	LABEL        "08";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_09
{
	LABEL        "09";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_10
{
	LABEL        "10";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_11
{
	LABEL        "11";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_12
{
	LABEL        "12";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_13
{
	LABEL        "13";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_14
{
	LABEL        "14";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      Qrel_Value_15
{
	LABEL        "15";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_00
{
	LABEL        "00";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_01
{
	LABEL        "01";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_02
{
	LABEL        "02";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_03
{
	LABEL        "03";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_04
{
	LABEL        "04";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_05
{
	LABEL        "05";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_06
{
	LABEL        "06";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_07
{
	LABEL        "07";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_08
{
	LABEL        "08";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_09
{
	LABEL        "09";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_10
{
	LABEL        "10";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_11
{
	LABEL        "11";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_12
{
	LABEL        "12";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_13
{
	LABEL        "13";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_14
{
	LABEL        "14";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}

VARIABLE      A_B_Value_15
{
	LABEL        "15";
	CLASS   CORRECTION;
	TYPE    INTEGER(2);
}


/* local variables */
VARIABLE      direct_access_index
{
	LABEL        "Index:""|de|Index:";
	CLASS   LOCAL;
	TYPE    UNSIGNED_INTEGER;
}

VARIABLE      direct_access_data
{
	LABEL        "Value:""|de|Wert:";
	CLASS   LOCAL;
	TYPE    UNSIGNED_INTEGER(2);
}

VARIABLE        local_self_test_mask_1_01
{
	LABEL          "Q > 103%";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        local_self_test_mask_1_02
{
	LABEL          "Q <> Sensorlimits";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        local_self_test_mask_1_04
{
	LABEL          "Sensors too hot/cold" "|de|Sensoren zu hei/kalt";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        local_self_test_mask_1_08
{
	LABEL          "A-B not plausible" "|de|A-B nicht sinnvoll";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        local_self_test_mask_1_10
{
	LABEL          "Totalizer overflow" "|de|Zhlerberlauf";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}

VARIABLE        local_self_test_mask_1_20
{
	LABEL          "MIN/MAX limit" "|de|MIN/MAX-Grenzwert";
	CLASS   LOCAL;
	TYPE   ENUMERATED
	{
		{   	0, 	"off" "|de|aus"  },
		{   	1, 	"on" "|de|an"  }
	}
}





COMMAND    cmd_128
{
	NUMBER   128;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			para_minlimit, 	para_maxlimit
		}
		REPLY
		{
			response_code, device_status,
			para_minlimit, 	para_maxlimit
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		6, 	MISC_ERROR, [xmtr_specific_command_error];
		7, 	MODE_ERROR, [in_write_protect_mode];
		2, DATA_ENTRY_ERROR, "MIN >= MAX-2%";
		3, DATA_ENTRY_ERROR, "MIN too large, MAX>110%""|de|zu gro fr MIN oder MAX>110%";
	}
}
COMMAND    cmd_129
{
	NUMBER   129;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			para_minlimit, 	para_maxlimit
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}


COMMAND    cmd_130
{
	NUMBER   130;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}


COMMAND    cmd_131
{
	NUMBER   131;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
		para_output_status,namur_switch,totalizer_switch,current_output_alarm, self_test_mask_1 <0xfc>, 	floatmvment <0x03>, 	parity_check
		}
		REPLY
		{
			response_code, device_status,
			para_output_status, 	namur_switch, 	totalizer_switch, current_output_alarm, self_test_mask_1 <0xfc>, 	floatmvment <0x03>, 	parity_check
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}
COMMAND    cmd_132
{
	NUMBER   132;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			para_output_status, 	namur_switch, 	totalizer_switch, current_output_alarm, self_test_mask_1 <0xfc>, 	floatmvment <0x03>, 	parity_check
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_133
{
	NUMBER   133;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			default_Qrel_output, 	simulation_switch, 	default_N1, default_N2, default_current, 	default_Qrel
		}
		REPLY
		{
			response_code, device_status,
			default_Qrel_output, 	simulation_switch, 	default_N1, default_N2, default_current, 	default_Qrel
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		6, 	MISC_ERROR, [xmtr_specific_command_error];
		7, 	MODE_ERROR, [in_write_protect_mode];
		3, DATA_ENTRY_ERROR, "Default currrent/Qrel too large""|de|Stromvorgabe zu gro" "Qrel > 110%";
	}
}
COMMAND    cmd_134
{
	NUMBER   134;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			default_Qrel_output, 	simulation_switch, 	default_N1, default_N2, default_current, 	default_Qrel
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_135
{
	NUMBER   135;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			self_test_Qrel, 	self_test_delta, 	self_test_period
		}
		REPLY
		{
			response_code, device_status,
			self_test_Qrel, 	self_test_delta, 	self_test_period
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		6, 	MISC_ERROR, [xmtr_specific_command_error];
		7, 	MODE_ERROR, [in_write_protect_mode];
		3, DATA_ENTRY_ERROR, "Self test period > 5900 sec" "min. Qrel > 150%";
		4, DATA_ENTRY_ERROR, "Delta is negative";
	}
}
COMMAND    cmd_136
{
	NUMBER   136;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			self_test_Qrel, 	self_test_delta, 	self_test_period
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_137
{
	NUMBER   137;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			volume_flow_cutoff
		}
		REPLY
		{
			response_code, device_status,
			volume_flow_cutoff
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		6, 	MISC_ERROR, [xmtr_specific_command_error];
		7, 	MODE_ERROR, [in_write_protect_mode];
		3, DATA_ENTRY_ERROR, "Cut off <0, >110%""|de|kleiner als Null oder grer als 110% (auerhalb des gltigen Bereich)";
	}
}
COMMAND    cmd_138
{
	NUMBER   138;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			volume_flow_cutoff
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_139
{
	NUMBER   139;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			calibrate_unit, 	calibrate_end_value, 	calibrate_number_of_point, Atara, 	Btara, 	Amax, Bmax
		}
		REPLY
		{
			response_code, device_status,
			calibrate_unit, 	calibrate_end_value, 	calibrate_number_of_point, Atara, 	Btara, 	Amax, Bmax
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		7, 	MODE_ERROR, [in_write_protect_mode];
		3, DATA_ENTRY_ERROR, "Upper limit too large""|de|Endwert zu gro, Wert*1.1 > 32767" "Sttzpunkte kleiner 2, grer 16";
		6, DATA_ENTRY_ERROR, "Character curve not monoton ascend""|de|Kennlinie nicht monoton steigend";
	}
}


COMMAND    cmd_140
{
	NUMBER   140;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,
			calibrate_unit, 	calibrate_end_value, 	calibrate_number_of_point, Atara, 	Btara, Amax, Bmax
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}




COMMAND    cmd_141
{
	NUMBER   141;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{

			Qrel_Value_00,
			Qrel_Value_01,
			Qrel_Value_02,
			Qrel_Value_03,
			Qrel_Value_04,
			Qrel_Value_05,
			Qrel_Value_06,
			Qrel_Value_07,
			Qrel_Value_08,
			Qrel_Value_09,
			Qrel_Value_10,
			Qrel_Value_11
		}
		REPLY
		{
			response_code, device_status,

			Qrel_Value_00,
			Qrel_Value_01,
			Qrel_Value_02,
			Qrel_Value_03,
			Qrel_Value_04,
			Qrel_Value_05,
			Qrel_Value_06,
			Qrel_Value_07,
			Qrel_Value_08,
			Qrel_Value_09,
			Qrel_Value_10,
			Qrel_Value_11
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		7, 	MODE_ERROR, [in_write_protect_mode];
		4, DATA_ENTRY_ERROR, "Value negative""|de|Wert negativ";
		6, DATA_ENTRY_ERROR, "Character curve not monoton ascend""|de|Kennlinie nicht monoton steigend";
	}
}
COMMAND    cmd_142
{
	NUMBER   142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,

			Qrel_Value_00,
			Qrel_Value_01,
			Qrel_Value_02,
			Qrel_Value_03,
			Qrel_Value_04,
			Qrel_Value_05,
			Qrel_Value_06,
			Qrel_Value_07,
			Qrel_Value_08,
			Qrel_Value_09,
			Qrel_Value_10,
			Qrel_Value_11
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_143
{
	NUMBER   143;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{

			A_B_Value_00,
			A_B_Value_01,
			A_B_Value_02,
			A_B_Value_03,
			A_B_Value_04,
			A_B_Value_05,
			A_B_Value_06,
			A_B_Value_07,
			A_B_Value_08,
			A_B_Value_09,
			A_B_Value_10,
			A_B_Value_11
		}
		REPLY
		{
			response_code, device_status,

			A_B_Value_00,
			A_B_Value_01,
			A_B_Value_02,
			A_B_Value_03,
			A_B_Value_04,
			A_B_Value_05,
			A_B_Value_06,
			A_B_Value_07,
			A_B_Value_08,
			A_B_Value_09,
			A_B_Value_10,
			A_B_Value_11
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		7, 	MODE_ERROR, [in_write_protect_mode];
		4, DATA_ENTRY_ERROR, "Value negative""|de|Wert negativ";
		6, DATA_ENTRY_ERROR, "Character curve not monoton ascend""|de|Kennlinie nicht monoton steigend";
	}
}
COMMAND    cmd_144
{
	NUMBER   144;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,

			A_B_Value_00,
			A_B_Value_01,
			A_B_Value_02,
			A_B_Value_03,
			A_B_Value_04,
			A_B_Value_05,
			A_B_Value_06,
			A_B_Value_07,
			A_B_Value_08,
			A_B_Value_09,
			A_B_Value_10,
			A_B_Value_11
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_145
{
	NUMBER   145;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{
			direct_access_index, direct_access_data
		}
		REPLY
		{
			response_code, device_status,
			direct_access_index, direct_access_data
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}
COMMAND    cmd_146
{
	NUMBER   146;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{
			direct_access_index, direct_access_data
		}
		REPLY
		{
			response_code, device_status,
			direct_access_index, direct_access_data
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}



COMMAND    cmd_147
{
	NUMBER   147;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{
			calibrate_point_index, 	calibrate_point_flow
		}
		REPLY
		{
			response_code, device_status,
			calibrate_point_index, 	calibrate_point_flow
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		6, 	MISC_ERROR, [xmtr_specific_command_error];
		7, 	MODE_ERROR, [in_write_protect_mode];
		2, DATA_ENTRY_ERROR, "Point index <0, >15";
		3, DATA_ENTRY_ERROR, "Value>130% or negative""|de|Wert>130% oder negativ";
	}
}

COMMAND    cmd_148
{
	NUMBER   148;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		7, 	MODE_ERROR, [in_write_protect_mode];
		6, DATA_ENTRY_ERROR, "Character curve not monoton ascend""|de|Kennlinie nicht monoton steigend";
	}
}


COMMAND    cmd_151
{
	NUMBER   151;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{

			A_B_Value_12,
			A_B_Value_13,
			A_B_Value_14,
			A_B_Value_15,
			Qrel_Value_12,
			Qrel_Value_13,
			Qrel_Value_14,
			Qrel_Value_15
		}
		REPLY
		{
			response_code, device_status,

			A_B_Value_12,
			A_B_Value_13,
			A_B_Value_14,
			A_B_Value_15,
			Qrel_Value_12,
			Qrel_Value_13,
			Qrel_Value_14,
			Qrel_Value_15
		}
	}
	RESPONSE_CODES
	{
		0, 	SUCCESS, 	[no_command_specific_errors];
		2, 	DATA_ENTRY_ERROR, 	[invalid_selection];
		7, 	MODE_ERROR, [in_write_protect_mode];
		4, DATA_ENTRY_ERROR, "Value negative""|de|Wert negativ";
		6, DATA_ENTRY_ERROR, "Character curve not monoton ascend""|de|Kennlinie nicht monoton steigend";
	}
}
COMMAND    cmd_152
{
	NUMBER   152;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status,

			A_B_Value_12,
			A_B_Value_13,
			A_B_Value_14,
			A_B_Value_15,
			Qrel_Value_12,
			Qrel_Value_13,
			Qrel_Value_14,
			Qrel_Value_15
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}




COMMAND    cmd_153
{
	NUMBER   153;
	OPERATION COMMAND;
	TRANSACTION
	{
		REQUEST
		{

		}
		REPLY
		{
			response_code, device_status
		}
	}
	RESPONSE_CODES
	{
		__ALL_RESPONSE_LIST
	}
}


/*---------------------------------------------------------------*/
/*      relations */
UNIT pv_unit_relation
  {
	flow_units:
	flow_value,
	calibrate_end_value,
	flow_upper_range_value,
	flow_lower_range_value,
	flow_upper_sensor_limit,
	flow_lower_sensor_limit,
	flow_minimum_span,
calibrate_point_flow
    }

REFRESH pv_range_refresh
{

	flow_upper_range_value,
	flow_lower_range_value:
	flow_value
}

UNIT sv_unit_relation
{

	totl_units:
	totl_value
}

/*
UNIT calibrate_unit_relation \n{\n
  calibrate_unit:
  calibrate_end_value
}
*/
REFRESH end_value_refresh
{

	calibrate_end_value, calibrate_unit:
	flow_units, flow_range_units,
	flow_upper_range_value,
	flow_upper_sensor_limit
}

/*---------------------------------------------------------------*/

METHOD update_calibration_data
{
	DEFINITION
	{
		send_command(140);
		send_command(142);
		send_command(144);
		send_command(152);
		save_values();
	}
}

METHOD zero_trim_method
{
	LABEL [menu_zero_trim];

	HELP [zero_trim_help];

	DEFINITION
	{
		char status[STATUS_SIZE];
		int retry;
		char disp_string1[60];
		char disp_string2[60];
		int slen1;
		int slen2;

		slen1=60;
		slen2=60;

		IGNORE_ALL_RESPONSE_CODES();

//		get_dictionary_string(remove_loop_from_auto,disp_string1,slen1);
//		ACKNOWLEDGE(disp_string1);
//		add_abort_method(return_to_normal);
//		get_dictionary_string(this_will_affect_snsr_cal,disp_string1,slen1);
//		ACKNOWLEDGE(disp_string1);

		do {
//			get_dictionary_string(apply_0_input_to_snsr,disp_string1,slen1);
//			ACKNOWLEDGE(disp_string1);

//			get_dictionary_string(snsr_input_stabilizing,disp_string1,slen1);
//			DELAY(3,disp_string1);

			send(130,status);
			if (status[STATUS_RESPONSE_CODE]==0x20) {	/* -change- */
				DELAY_TIME(2);														/* - - - - */
				send(130,status);													/* - - - - */
			}
			if (status[STATUS_RESPONSE_CODE])
			 {
				display_response_status(130,status[STATUS_RESPONSE_CODE]);
				if ((status[STATUS_RESPONSE_CODE] != 9)
				&& (status[STATUS_RESPONSE_CODE] != 10)) {
					get_dictionary_string(abort_last_error,disp_string1,slen1);
					DELAY(2,disp_string1);
					process_abort();
			 }
			get_dictionary_string(zero_the_input_and_try_again,disp_string1,slen1);
			get_dictionary_string(yes_no,disp_string2,slen2);
			retry=SELECT_FROM_LIST(disp_string1,disp_string2);
			}
			else {
		//		get_dictionary_string(snsr_zero_succeeded,disp_string1,slen1);
		//		DELAY(3,disp_string1);

				add_abort_method(update_calibration_data);/* -change- */
		//		add_abort_method(burn_eeprom);						/* - - - - */
				process_abort();
			}
		} while (!retry);
		process_abort();
	}
}

METHOD undo_trim_method
{
	LABEL  [undo_zero_trim];
	HELP [undo_zero_trim_help];

	DEFINITION
	{
		ACKNOWLEDGE([undo_zero_trim]);
		send_command(153);

		add_abort_method(update_calibration_data);/* -change- */
		add_abort_method(burn_eeprom);						/* - - - - */
		process_abort();
	}
}

METHOD wet_calibrate_method
{
	LABEL "Calibrate""""|de|Kalibrieren";

	DEFINITION
	{
		long ids[2];

		ids[0]=VARID(calibrate_point_index);
		ids[1]=VARID(calibrate_point_flow);
	//	acknowledge("Index: %{0} \nValue: %{1}", ids);

		send_command(147);

		add_abort_method(update_calibration_data);
		process_abort();
	}
}

METHOD reset_totalizer_method
{
	LABEL  "Reset totalizer""|de|Zhler rcksetzen";

	DEFINITION
	{
		ACKNOWLEDGE("Reset totalizer ?""|de|Zhler rcksetzen ?");
		iassign(transmitter_variable_code, 2);
		send_command(52);
	}
}

METHOD reset_change_flag_method
{
	LABEL  [configuration_flag_reset];
	HELP   [configuration_flag_reset_help];
	DEFINITION
	{
		ACKNOWLEDGE([configuration_flag_reset]);
		send_command(38);
	}
}

METHOD reset_device_method
{
	LABEL  "Reset device ?|fr|RAZ instrument""|de|Gert rcksetzen ?";

	DEFINITION
	{
		ACKNOWLEDGE("Reset device|fr|RAZ instrument""|de|Gert rcksetzen");
		send_command(42);
	}
}

METHOD simulation_method
{
	LABEL   "Start simulation""|de| Simulation starten ";
	CLASS CORRECTION;
	DEFINITION
	{
		long ids[4];
		char status[STATUS_SIZE];

		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();
		add_abort_method(simulation_abort_method);
		iassign(simulation_switch, 1);
		send(133, status);
		if (status[STATUS_RESPONSE_CODE]!=0x00) {
			display_response_status(133,status[STATUS_RESPONSE_CODE]);
			process_abort();
		}

		ids[0] = VARID(totl_value);
		ids[1] = VARID(flow_value);
		ids[2] = VARID(totl_units);
		ids[3] = VARID(flow_units);
		// PDM: Beobachtung in Mewertanzeige
		//do {
			//	send_command(3);
			//	delay(2," Simulation ...\n\nTotl %{0} %{2}\nFlow %{1} %{3}", ids);
			//} while (1);
	}
}
METHOD simulation_abort_method
{
	LABEL   "End simulation""|de| Simulation beenden ";

	DEFINITION
	{
		iassign(simulation_switch, 0);
		send_command(133);
	}
}

METHOD direct_access_read
{
	LABEL "Read data""|de| Inhalt lesen ";

	DEFINITION
	{
		long ids[2];

		send_command(146);
		ids[0]=VARID(direct_access_index);
		ids[1]=VARID(direct_access_data);
//		acknowledge("Index: %{0} \nValue: %{1}", ids);
	}
}

METHOD direct_access_write
{
	LABEL "Write data""|de| Inhalt schreiben ";

	DEFINITION
	{
		long ids[2];

		ids[0]=VARID(direct_access_index);
		ids[1]=VARID(direct_access_data);
//		acknowledge("Index: %{0} \nValue: %{1}", ids);
		send_command(145);
	}
}

METHOD save_without_initialization_method
  {
  DEFINITION
    {
    send_command(39);
    }
  }

METHOD save_calibration_method
  {
	LABEL "init and save""|de| Initialisieren und Sichern ";

	DEFINITION
	{
		char status[STATUS_SIZE];

		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();

//		ACKNOWLEDGE("Init/save""|de| Initialisieren/Sichern ");
		send(148,status);
		if (status[STATUS_RESPONSE_CODE]==0x20) {
			DELAY_TIME(4);
			send(148,status);
			if (status[STATUS_RESPONSE_CODE]!=0) {
				display_response_status(148,status[STATUS_RESPONSE_CODE]);
				abort();
			}
		}
		if (status[STATUS_RESPONSE_CODE]==0x06) {
			display_response_status(148,status[STATUS_RESPONSE_CODE]);
		}


		add_abort_method(update_calibration_data);
		process_abort();
	}
}

METHOD method_read_self_test_mask_1
{
	DEFINITION
	{
		long	self_test_mask;

		self_test_mask = lvar_value(self_test_mask_1);
		if (self_test_mask & 0x01)
		iassign(local_self_test_mask_1_01, 1);
		else
		iassign(local_self_test_mask_1_01, 0);
		if (self_test_mask & 0x02)
		iassign(local_self_test_mask_1_02, 1);
		else
		iassign(local_self_test_mask_1_02, 0);

		if (self_test_mask & 0x04)
		iassign(local_self_test_mask_1_04, 1);
		else
		iassign(local_self_test_mask_1_04, 0);

		if (self_test_mask & 0x08)
		iassign(local_self_test_mask_1_08, 1);
		else
		iassign(local_self_test_mask_1_08, 0);

		if (self_test_mask & 0x10)
		iassign(local_self_test_mask_1_10, 1);
		else
		iassign(local_self_test_mask_1_10, 0);

		if (self_test_mask & 0x20)
		iassign(local_self_test_mask_1_20, 1);
		else
		iassign(local_self_test_mask_1_20, 0);

	}
}

METHOD  method_write_self_test
{
	LABEL		[transfer];
	HELP		[transfer_help];
	DEFINITION
	{
		char status[STATUS_SIZE];
		long	self_test_mask;

		self_test_mask = lvar_value(self_test_mask_1);
		if (ivar_value(local_self_test_mask_1_01) != 0)
		self_test_mask = self_test_mask | 0x01;
		else
		self_test_mask = self_test_mask & ~0x01;

		if (ivar_value(local_self_test_mask_1_02) != 0)
		self_test_mask = self_test_mask | 0x02;
		else
		self_test_mask = self_test_mask & ~0x02;

		if (ivar_value(local_self_test_mask_1_04) != 0)
		self_test_mask = self_test_mask | 0x04;
		else
		self_test_mask = self_test_mask & ~0x04;

		if (ivar_value(local_self_test_mask_1_08) != 0)
		self_test_mask = self_test_mask | 0x08;
		else
		self_test_mask = self_test_mask & ~0x08;

		if (ivar_value(local_self_test_mask_1_10) != 0)
		self_test_mask = self_test_mask | 0x10;
		else
		self_test_mask = self_test_mask & ~0x10;

		if (ivar_value(local_self_test_mask_1_20) != 0)
		self_test_mask = self_test_mask | 0x20;
		else
		self_test_mask = self_test_mask & ~0x20;

		lassign (self_test_mask_1, self_test_mask);

/*		send (131, status);


		// Code von save_calibration_method: Beginn
		IGNORE_ALL_RESPONSE_CODES();
		XMTR_IGNORE_ALL_RESPONSE_CODES();
		IGNORE_ALL_DEVICE_STATUS();
		XMTR_IGNORE_ALL_DEVICE_STATUS();
		ACKNOWLEDGE("Init&save");
		send(148,status);
		if (status[STATUS_RESPONSE_CODE]==0x20) {
			DELAY_TIME(4);
			send(148,status);
			if (status[STATUS_RESPONSE_CODE]!=0) {
				display_response_status(148,status[STATUS_RESPONSE_CODE]);
				abort();
			}
		}
		add_abort_method(update_calibration_data);
		process_abort();
		// Code von save_calibration_method: Ende
*/
	}
}

//ad-wandler abfragen, das geht z.zt. nur mit debug

//englisch ausprobieren
//selbsttestmaske upload/download: wie "geladen" melden?
//evt. impwertigkeit
//sichern mit 39 oder 148, evt.Problem et200 mit busy
//onlinediagnose texte
//es bei bayer sagt 0x3 fr floatmvment